from setuptools import setup
setup(name='flakynetworksimulator', #Package_Name
      version='9.1.1',
      description='Simple Python Placeholder Package By Predator_97',
      author='Predator_97',
      license='MIT',
      zip_safe=False
     )
